function [ f_ion ] = ion_beam( p, pstar, fstar, w1, w2, alpha )
% -------------------------------------------------------------------------
%
% NAME
%
%	ion_beam
%
% PURPOSE
%
%	This routine creates a double Gaussian ion beam with the prescribed
%   parameters.
%
% CALLING SEQUENCE
%
%	[ f_ion ] = ion_beam( p, pstar, fstar, w1, w2, alpha )
%
% INPUT PARAMETERS
%   
%   p
%     pixel vector
%
%   pstar
%     position of the centre of the ion beam
%
%   fstar
%     peak ion flux
%
%   w1, w2, alpha
%     half-widths of both Gaussian components and relative importance of
%     the secondary Gaussian
%
% OUTPUT PARAMETERS
%
%   f_ion
%     ion flux profile, same format as p
%
% AUTHOR
%
%   (c) Johan De Keyser - Royal Belgian Institute for Space Aeronomy - 2019
%
% HISTORY
%
%   2019-05-15 : v0.0
%     Initial version
%
% -------------------------------------------------------------------------
    
    % create ion beam
    f_ion = fstar * double_gaussian( p, pstar, w1, w2, alpha );

end

% =========================================================================
